package ro.sync.ecss.extensions.commons;
import org.apache.log4j.Logger;

import ro.sync.ecss.extensions.api.link.ElementLocator;
import ro.sync.ecss.extensions.api.link.ElementLocatorException;
import ro.sync.ecss.extensions.api.link.ElementLocatorProvider;
import ro.sync.ecss.extensions.api.link.IDTypeVerifier;

/**
 * Default implementation for locating elements based on a given link.
 * Depending on the link structure the following cases are covered:
 * - xinclude element scheme : element(/1/2) see
 * http://www.w3.org/TR/2003/REC-xptr-element-20030325/
 * - ID based links : the link represents the value of an attribute of type ID
 */
public class DefaultElementLocatorProvider implements ElementLocatorProvider {
  
  /**
   * Logger for logging. 
   */
  private static Logger logger = Logger.getLogger(DefaultElementLocatorProvider.class.getName());
  
  /**
   * @see ro.sync.ecss.extensions.api.link.ElementLocatorProvider#
   * getElementLocator(ro.sync.ecss.extensions.api.link.IDTypeVerifier,
   * java.lang.String)
   */
  public ElementLocator getElementLocator(IDTypeVerifier idVerifier,
      String link) {
    ElementLocator elementLocator = null;
    try {
      if(link.startsWith("element(")){
        // xpointer element() scheme
        elementLocator = new XPointerElementLocator(idVerifier, link);
      } else {
        // Locate link element by ID
        elementLocator = new IDElementLocator(idVerifier, link);
      }
    } catch (ElementLocatorException e) {
      logger.warn("Exception when create element locator for link: "
          + link + ". Cause: " + e, e);
    }
    return elementLocator;
  }
  
  /**
   * @see ro.sync.ecss.extensions.api.Extension#getDescription()
   */
  public String getDescription() {
    return
    "Default implementation for locating elements based on a given link. \n" +
    "The following cases are covered: xinclude element scheme "
    + "and ID based links.";
  }
}