package ro.sync.ecss.extensions.commons;
import ro.sync.ecss.extensions.api.link.Attr;
import ro.sync.ecss.extensions.api.link.ElementLocator;
import ro.sync.ecss.extensions.api.link.ExtensionUtil;
import ro.sync.ecss.extensions.api.link.IDTypeVerifier;

/**
 * Implementation of an ElementLocator that treats the link as the value of an
 * attribute with the type ID.
 */
public class IDElementLocator extends ElementLocator {
  
  /**
   * Class able to tell if a given attribute is of type ID.
   */
  private IDTypeVerifier idVerifier;
  
  /**
   * Constructor.
   *
   * @param idVerifier It tells us if an attribute is of type ID.
   * @param link The link used to identify an element.
   */
  public IDElementLocator(IDTypeVerifier idVerifier, String link) {
    super(link);
    this.idVerifier = idVerifier;
  }
  
  /**
   * @see ro.sync.ecss.extensions.api.link.ElementLocator#endElement(
   * java.lang.String, java.lang.String, java.lang.String)
   */
  @Override
  public void endElement(String uri, String localName, String name) {
    // Nothing to do.
  }
  
  /**
   * @see ro.sync.ecss.extensions.api.link.ElementLocator#startElement(
   * java.lang.String, java.lang.String, java.lang.String,
   * ro.sync.ecss.extensions.api.link.Attr[])
   */
  @Override
  public boolean startElement(String uri, String localName,
      String name, Attr[] atts) {
    boolean elementFound = false;
    for (int i = 0; i < atts.length; i++) {
      if (link.equals(atts[i].getValue())) {
        if("xml:id".equals(atts[i].getQName())) {
          // xml:id attribute
          elementFound = true;
        } else {
          // check if attribute has ID type
          String attrLocalName =
            ExtensionUtil.getLocalName(atts[i].getQName());
          String attrUri = atts[i].getNamespace();
          if (idVerifier.hasIDType(localName, uri, attrLocalName, attrUri)) {
            elementFound = true;
          }
        }
      }
    }
    return elementFound;
  }
}