/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2007 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package simple.documentation.framework.operations;

import java.awt.event.ActionEvent;
import java.util.List;

import javax.swing.AbstractAction;
import javax.swing.JFrame;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.text.BadLocationException;

import ro.sync.contentcompletion.xml.CIElement;
import ro.sync.contentcompletion.xml.WhatElementsCanGoHereContext;
import ro.sync.ecss.extensions.api.ArgumentDescriptor;
import ro.sync.ecss.extensions.api.ArgumentsMap;
import ro.sync.ecss.extensions.api.AuthorAccess;
import ro.sync.ecss.extensions.api.AuthorOperation;
import ro.sync.ecss.extensions.api.AuthorOperationException;
import ro.sync.ecss.extensions.api.AuthorSchemaManager;
import ro.sync.ecss.extensions.api.node.AuthorDocumentFragment;
import ro.sync.exml.view.graphics.Point;
import ro.sync.exml.view.graphics.Rectangle;

/**
 * Show a popup menu that contains the name of all elements that can be inserted at the caret offset.
 */
public class InsertElementOperation implements AuthorOperation {

  /**
   * @see ro.sync.ecss.extensions.api.AuthorOperation#doOperation(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.ArgumentsMap)
   */
  /** 
   * @see ro.sync.ecss.extensions.api.AuthorOperation#doOperation(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.ArgumentsMap) 
   */ 
  public void doOperation(final AuthorAccess authorAccess, ArgumentsMap args) 
      throws IllegalArgumentException, AuthorOperationException { 
    try { 
      //Get the caret offset 
      final int caretOffset = authorAccess.getEditorAccess().getCaretOffset(); 
      //The schema manager 
      final AuthorSchemaManager schemaManager = authorAccess.getDocumentController().getAuthorSchemaManager(); 
      //The context of elements. 
      WhatElementsCanGoHereContext ctxt = schemaManager.createWhatElementsCanGoHereContext(caretOffset); 
      //Get the list of elements which can be inserted here 
      final List<CIElement> childrenElements = schemaManager.getChildrenElements(ctxt); 
      JPopupMenu jpo = new JPopupMenu(); 
      for (int i = 0; i < childrenElements.size(); i++) { 
        final int index = i; 
        jpo.add(new JMenuItem(new AbstractAction(childrenElements.get(index).getName()) { 
          public void actionPerformed(ActionEvent e) { 
            CIElement toInsert = childrenElements.get(index); 
            try { 
              //The CIElement contains all data necessary to make a small XML fragment with 
              //the string to insert and then call 
              // authorAccess.getDocumentController().createNewDocumentFragmentInContext(xmlFragment, caretOffset); 
              //But Oxygen 11.2 will come with a easier method: 
              //Create a document fragment from the CIElement. 
              AuthorDocumentFragment frag = schemaManager.createAuthorDocumentFragment(toInsert); 
              //Now you can process the fragment and remove/add attributes. 
              authorAccess.getDocumentController().insertFragment(caretOffset, frag); 
            } catch (BadLocationException e1) { 
              e1.printStackTrace(); 
            } 
          } 
        })); 
      } 
      Rectangle mtv = authorAccess.getEditorAccess().modelToViewRectangle(caretOffset); 
      Point popupLocation = authorAccess.getEditorAccess().getLocationOnScreenAsPoint(mtv.x, mtv.y);
      jpo.setLocation(popupLocation.x, popupLocation.y);
      JFrame oxygenFrame = (JFrame)authorAccess.getWorkspaceAccess().getParentFrame();
      // Show popup menu
      jpo.show(oxygenFrame, popupLocation.x - oxygenFrame.getLocation().x, popupLocation.y - oxygenFrame.getLocation().y); 
    } catch (BadLocationException e) { 
      e.printStackTrace(); 
    } 
  } 

  /**
   * @see ro.sync.ecss.extensions.api.AuthorOperation#getArguments()
   */
  public ArgumentDescriptor[] getArguments() {
    return null;
  }

  /**
   * @see ro.sync.ecss.extensions.api.Extension#getDescription()
   */
  public String getDescription() {
    return "Insert element at the caret position.";
  }

}
