/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2007 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package ro.sync.ecss.extensions.api;

import ro.sync.ecss.extensions.api.node.AuthorNode;

/**
 * AuthorCaretEvent is used to notify interested {@link AuthorCaretListener} that 
 * the position of the caret has changed in the Author editor page.
 */
public class AuthorCaretEvent {
  /**
   * The absolute caret position inside the Author editor page.
   */
  private int offset;
  
  /**
   * The node holding the current caret offset.
   */
  private AuthorNode node;

  /**
   * The selection start offset, inclusive. If no selection the selection start is equals with caret offset.
   */
  private final int selStart;

  /**
   * The selection end offset, exclusive. If no selection the selection end is equals with caret offset.
   */
  private final int selEnd;
  
  /**
   * Constructor for the AuthorCaretEvent.
   * 
   * @param offset The absolute caret position inside the Author page.
   * @param selStart The selection start offset. If no selection the selection start is equals with caret offset.
   * @param selEnd  The selection end offset. If no selection the selection end is equals with caret offset.
   * @param node The node holding the caret offset.
   */
  public AuthorCaretEvent(int offset, int selStart, int selEnd, AuthorNode node) {
    this.offset = offset;
    this.selStart = selStart;
    this.selEnd = selEnd;
    this.node = node;
  }
  
  /**
   * @return Returns the absolute caret offset.
   */
  public int getOffset() {
    return offset;
  }
  
  /**
   * @return Returns the node holding the caret position.
   */
  public AuthorNode getNode() {
    return node;
  }
  
  /**
   * @return Returns the selection start offset, inclusive. 
   * If no selection the selection start is equals with caret offset.
   */
  public int getSelectionStart() {
    return selStart;
  }
  
  /**
   * @return Returns the selection end offset, exclusive. 
   * If no selection the selection end is equals with caret offset.
   */
  public int getSelectionEnd() {
    return selEnd;
  }
}