/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2009 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package ro.sync.ecss.extensions.api;

/**
 * The base interface for all Oxygen extensions classes.
 * This interface is extended by two more specific interfaces
 * {@link SWTExtension} and {@link AWTExtension} which divide the extensions
 * into two subcategories SWT Eclipse extensions and AWT extensions.
 * There are several kinds of extensions:
 * <ul>
 * <li>
 * {@link ExtensionsBundle} representing a bundle for all extensions handlers,
 * </li><li>
 * {@link AuthorExtensionStateListener} notified when the Document Type where
 * the listener is defined was activated or deactivated in the detection process,
 * </li><li>
 * {@link AuthorOperation} defining an author extension operation, 
 * </li><li>
 * {@link AuthorReferenceResolver} for the custom handlers used to expand content
 * references, 
 * </li><li>
 * {@link AuthorTableCellSpanProvider} for classes which are responsible for
 * providing information about the cell spanning,
 * </li><li>
 * {@link AuthorTableColumnWidthProvider} for classes which are responsible for 
 * providing information and handling modifications regarding table and column 
 * widths,
 * </li><li>
 * {@link com.oxygenxml.editor.editors.TextDnDListener}, 
 * {@link com.oxygenxml.editor.editors.author.AuthorDnDListener} 
 * and  {@link ro.sync.exml.editor.xmleditor.pageauthor.AuthorDnDListener} 
 * extension listener for drag and drop operations,
 * </li><li>
 * {@link DocumentTypeCustomRuleMatcher} for providing custom matching to the
 * document type it belongs to, 
 * </li><li>
 * {@link ro.sync.ecss.extensions.api.link.ElementLocatorProvider} capable of locating an element pointed by 
 * the supplied link,
 * </li><li>
 * {@link ro.sync.contentcompletion.xml.SchemaManagerFilter} filter for the schema manager, 
 * </li><li>
 * {@link StylesFilter} filter for the stylesheet's styles.  
 * </li>
 * </ul>
 */
public interface Extension {
  /**
   * @return The description of the extension.
   */
  String getDescription();
}